##  Step 4: Update Relations to IT Components
After importing the tech categories, update relations between the IT components and tech categories linked to the reference catalog.
Follow these steps:
  1. In the Reference Catalog section of the administration area, go to the IT Component tab.
  2. Under Relation to Tech Category, enable the Add relation to tech category when linking an IT component option.
  3. Choose Resync IT Components.
